@@ -53,13 +53,13 @@ class StartModule():
     def help(self):
         Logger.printMessage(message=ht.getFunctionsNamesFromModule('ht_phising'), debug_module=True)
     
-    def search(self, urls=[], gsb_api=None):
+    def search(self, urls, gsb_api=None):
         if not gsb_api:
             gsb_api = ht.Config.getAPIKey('gsb_api', gsb_api)
             
         if gsb_api:
             if urls:
-                threatentries = [{'url': url} for url in urls]
+                threatentries = [{'url': url.strip()} for url in urls.split(',')]
                 data = {
 					'client': self.client,
 					'threatInfo': {
